@@ -1,6 +1,10 @@
+//@line 41 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/components/printing/content/printUtils.js"
 
 var  XUL_NS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
 
+var gPrintSettingsAreGlobal = false;
+var gSavePrintSettings = false;
+
 var PrintUtils = {
 
   showPageSetup: function ()
@@ -10,8 +14,12 @@ var PrintUtils = {
       var PRINTPROMPTSVC = Components.classes["@mozilla.org/embedcomp/printingprompt-service;1"]
                                      .getService(Components.interfaces.nsIPrintingPromptService);
       PRINTPROMPTSVC.showPageSetup(window, printSettings, null);
-      this.savePrintSettings(printSettings);
-
+      if (gSavePrintSettings) {
+        // Page Setup data is a "native" setting on the Mac
+        var PSSVC = Components.classes["@mozilla.org/gfx/printsettings-service;1"]
+                              .getService(Components.interfaces.nsIPrintSettingsService);
+        PSSVC.savePrintSettingsToPrefs(printSettings, true, printSettings.kInitSaveNativeData);
+      }
     } catch (e) {
       dump("showPageSetup "+e+"\n");
       return false;
@@ -25,6 +33,14 @@ var PrintUtils = {
     var printSettings = this.getPrintSettings();
     try {
       webBrowserPrint.print(printSettings, null);
+      if (gPrintSettingsAreGlobal && gSavePrintSettings) {
+        var PSSVC = Components.classes["@mozilla.org/gfx/printsettings-service;1"]
+                              .getService(Components.interfaces.nsIPrintSettingsService);
+        PSSVC.savePrintSettingsToPrefs(printSettings, true,
+                                       printSettings.kInitSaveAll);
+        PSSVC.savePrintSettingsToPrefs(printSettings, false,
+                                       printSettings.kInitSavePrinterName);
+      }
     } catch (e) {
       // Pressing cancel is expressed as an NS_ERROR_ABORT return value,
       // causing an exception to be thrown which we catch here.
@@ -35,11 +51,20 @@ var PrintUtils = {
 
   printPreview: function (aEnterPPCallback, aExitPPCallback)
   {
-    // if we're in PP mode, don't copy the callbacks.
-    if (!document.getElementById("print-preview-toolbar")) {
+    // if we're already in PP mode, don't set the callbacks; chances
+    // are they're null because someone is calling printPreview() to
+    // get us to refresh the display.
+    var pptoolbar = document.getElementById("print-preview-toolbar");
+    if (!pptoolbar) {
       this._onEnterPP = aEnterPPCallback;
       this._onExitPP  = aExitPPCallback;
+    } else {
+      // hide the toolbar here -- it will be shown in
+      // onEnterPrintPreview; this forces a reflow which fixes display
+      // issues in bug 267422.
+      pptoolbar.hidden = true;
     }
+
     this._webProgressPP = {};
     var ppParams        = {};
     var notifyOnOpen    = {};
@@ -78,13 +103,6 @@ var PrintUtils = {
                    .getInterface(Components.interfaces.nsIWebBrowserPrint);
   },
 
-  savePrintSettings: function (aPrintSettings)
-  {
-    var PSSVC = Components.classes["@mozilla.org/gfx/printsettings-service;1"]
-                          .getService(Components.interfaces.nsIPrintSettingsService);
-    PSSVC.savePrintSettingsToPrefs(aPrintSettings, false, aPrintSettings.kInitSaveNativeData);
-  },
-
   ////////////////////////////////////////
   // "private" methods. Don't use them. //
   ////////////////////////////////////////
@@ -102,12 +120,23 @@ var PrintUtils = {
 
   getPrintSettings: function ()
   {
+    var pref = Components.classes["@mozilla.org/preferences-service;1"]
+                         .getService(Components.interfaces.nsIPrefBranch);
+    if (pref) {
+      gPrintSettingsAreGlobal = pref.getBoolPref("print.use_global_printsettings", false);
+      gSavePrintSettings = pref.getBoolPref("print.save_print_settings", false);
+    }
+
     var printSettings;
     try {
       var PSSVC = Components.classes["@mozilla.org/gfx/printsettings-service;1"]
                             .getService(Components.interfaces.nsIPrintSettingsService);
-      printSettings = PSSVC.globalPrintSettings;
-      this.setPrinterDefaultsForSelectedPrinter(PSSVC, printSettings);
+      if (gPrintSettingsAreGlobal) {
+        printSettings = PSSVC.globalPrintSettings;
+        this.setPrinterDefaultsForSelectedPrinter(PSSVC, printSettings);
+      } else {
+        printSettings = PSSVC.newPrintSettings;
+      }
     } catch (e) {
       dump("getPrintSettings: "+e+"\n");
     }
@@ -154,6 +183,7 @@ var PrintUtils = {
     var printPreviewTB = document.getElementById("print-preview-toolbar");
     if (printPreviewTB) {
       printPreviewTB.updateToolbar();
+      printPreviewTB.hidden = false;
       return;
     }
 
@@ -163,6 +193,7 @@ var PrintUtils = {
     printPreviewTB.setAttribute("printpreview", true);
     printPreviewTB.setAttribute("id", "print-preview-toolbar");
 
+//@line 244 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/components/printing/content/printUtils.js"
 
     // copy the window close handler
     if (document.documentElement.hasAttribute("onclose"))
@@ -175,7 +206,7 @@ var PrintUtils = {
     window.addEventListener("keypress", this.onKeyPressPP, true);
  
     _content.focus();
-    
+
     // on Enter PP Call back
     if (this._onEnterPP) {
       this._onEnterPP();
@@ -187,8 +218,10 @@ var PrintUtils = {
   {
     window.removeEventListener("keypress", this.onKeyPressPP, true);
 
+//@line 269 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/components/printing/content/printUtils.js"
     BrowserExitPrintPreview(); // make the traditional call..don't do any of the inline toolbar browser stuff
     return;
+//@line 272 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/components/printing/content/printUtils.js"
 
     // restore the old close handler
     document.documentElement.setAttribute("onclose", this._closeHandlerPP);
