@@ -1,3 +1,4 @@
+//@line 36 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/extensions/newsblog/content/am-newsblog.js"
 
 var gIncomingServer;
 
@@ -28,6 +29,6 @@ function manageSubscriptions()
   if (lastSubscriptionWindow)
     lastSubscriptionWindow.focus();
   else 
-    window.openDialog("chrome://messenger-newsblog/content/subscriptions.xul", "",
-                      "centerscreen,resizable=yes", { server: gIncomingServer});
-}
\ No newline at end of file
+    window.openDialog("chrome://messenger-newsblog/content/feed-subscriptions.xul", "",
+                      "centerscreen,chrome,dialog=no,resizable", { server: gIncomingServer});
+}
