@@ -1,3 +1,4 @@
+//@line 41 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/components/addrbook/content/abCardViewOverlay.js"
 
 //NOTE: gAddressBookBundle must be defined and set or this Overlay won't work
 
@@ -195,16 +196,11 @@ function DisplayCardViewPane(card)
   var goimURL = "aim:goim?screenname=" + card.aimScreenName;
   var hasScreenName = HandleLink(data.cvScreenname, zScreenName, card.aimScreenName, data.cvScreennameBox, goimURL);
   
-  if (!hasScreenName || gIOService.offline) {
-    data.cvAimPresence.removeAttribute("src");
-    data.cvAimPresence.removeAttribute("url");
-    data.cvAimPresence.setAttribute("width","0");
-  }
-  else {
-    data.cvAimPresence.setAttribute("src","http://big.oscar.aol.com:80/" + card.aimScreenName + "?on_url=http://ncmail.netscape.com/include/nc/images/online.gif&off_url=http://ncmail.netscape.com/include/nc/images/offline.gif");   
-    data.cvAimPresence.setAttribute("url", goimURL);
-    data.cvAimPresence.setAttribute("width","16");
-  }
+  data.cvAimPresence.removeAttribute("src");
+  data.cvAimPresence.removeAttribute("url");
+  data.cvAimPresence.setAttribute("width","0");
+
+//@line 249 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/components/addrbook/content/abCardViewOverlay.js"
 
   visible = hasScreenName || visible;
   visible = HandleLink(data.cvEmail2, zSecondaryEmail, card.secondEmail, data.cvEmail2Box, "mailto:" + card.secondEmail) || visible;
@@ -379,7 +375,7 @@ function cvSetNode(node, text)
 {
 	if ( node )
 	{
-		if ( node.childNodes.length == 0 )
+		if ( !node.hasChildNodes() )
 		{
 			var textNode = document.createTextNode(text);
 			node.appendChild(textNode);                   			
@@ -414,8 +410,8 @@ function cvAddAddressNodes(node, uri)
     if (addressList) {
       var total = addressList.Count();
       if (total > 0) {
-        for (var i = node.childNodes.length - 1; i >= 0; i--) {
-          node.removeChild(node.childNodes[i]);
+        while (node.hasChildNodes()) {
+          node.removeChild(node.lastChild);
         }
         for (i = 0;  i < total; i++ ) {
       		var descNode = document.createElement("description");   
