@@ -1,3 +1,4 @@
+//@line 41 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailContextMenus.js"
 
 //NOTE: gMessengerBundle must be defined and set or this Overlay won't work
 
@@ -19,8 +20,7 @@ function RestoreSelectionWithoutContentLoad(tree)
       return;
     }
 
-    var treeBoxObj = tree.treeBoxObject;
-    var treeSelection = treeBoxObj.selection;
+    var treeSelection = tree.view.selection;
 
     // make sure that currentIndex is valid so that we don't try to restore
     // a selection of an invalid row.
@@ -96,7 +96,9 @@ function fillThreadPaneContextMenu()
   EnableMenuItem("threadPaneContext-labels", (numSelected >= 1));
   EnableMenuItem("threadPaneContext-mark", (numSelected >= 1));
   SetupSaveAsMenuItem("threadPaneContext-saveAs", numSelected, false);
+//@line 141 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailContextMenus.js"
   SetupPrintPreviewMenuItem("threadPaneContext-printpreview", numSelected, false);
+//@line 143 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailContextMenus.js"
   SetupPrintMenuItem("threadPaneContext-print", numSelected, false);
   SetupDeleteMenuItem("threadPaneContext-delete", numSelected, false);
   SetupAddSenderToABMenuItem("threadPaneContext-addSenderToAddressBook", numSelected, false);
@@ -237,7 +239,7 @@ function fillFolderPaneContextMenu()
   var folderTree = GetFolderTree();
   var startIndex = {};
   var endIndex = {};
-  folderTree.treeBoxObject.selection.getRangeAt(0, startIndex, endIndex);
+  folderTree.view.selection.getRangeAt(0, startIndex, endIndex);
   if (startIndex.value < 0)
     return false;
   var numSelected = endIndex.value - startIndex.value + 1;
@@ -439,7 +441,9 @@ function fillMessagePaneContextMenu()
   SetupLabelsMenuItem("messagePaneContext-labels", numSelected, (numSelected == 0 || hideMailItems));
   SetupMarkMenuItem("messagePaneContext-mark", numSelected, (numSelected == 0 || hideMailItems));
   SetupSaveAsMenuItem("messagePaneContext-saveAs", numSelected, (numSelected == 0 || hideMailItems));
+//@line 488 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailContextMenus.js"
   SetupPrintPreviewMenuItem("messagePaneContext-printpreview", numSelected, (numSelected == 0 || hideMailItems));
+//@line 490 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailContextMenus.js"
 
   SetupPrintMenuItem("messagePaneContext-print", numSelected, (numSelected == 0 || hideMailItems));
   if (numSelected == 0 || hideMailItems)
