@@ -1,4 +1,4 @@
-//@line 38 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/base/content/msgHdrViewOverlay.js"
+//@line 38 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/base/content/msgHdrViewOverlay.js"
 
 
 /* This is where functions related to displaying the headers for a selected message in the
@@ -1662,6 +1662,9 @@ function nsDummyMsgHeader()
 
 nsDummyMsgHeader.prototype =
 {
+  mProperties : new Array,
+  getStringProperty : function(property) {return this.mProperties[property];},
+  setStringProperty : function(property, val) {this.mProperties[property] = val;},
   messageSize : 0,
   recipients : null,
   from : null,
